From: Uri Simchoni <uri@jdland.co.il>
To: linux-crypto@vger.kernel.org
Cc: Herbert Xu <herbert@gondor.apana.org.au>
Subject: [PATCHv2 6/10] crypto mv_cesa : Rename a variable to a more suitable name
Date: Thu, 08 Apr 2010 19:29:16 +0300 [thread overview]
Message-ID: <4BBE045C.5000900@jdland.co.il> (raw)
Rename a variable to a more suitable name
Signed-off-by: Uri Simchoni <uri@jdland.co.il>
---
diff -upr linux-2.6.32.8_p5/drivers/crypto/mv_cesa.c linux-2.6.32.8_p6/drivers/crypto/mv_cesa.c
--- linux-2.6.32.8_p5/drivers/crypto/mv_cesa.c 2010-03-16 11:43:37.443646086 +0200
+++ linux-2.6.32.8_p6/drivers/crypto/mv_cesa.c 2010-03-16 11:51:56.372211208 +0200
@@ -42,7 +42,7 @@ enum engine_status {
* @hw_nbytes: total bytes to process in hw for this request
* @sg_dst_left: bytes left dst to process in this scatter list
* @dst_start: offset to add to dst start position (scatter list)
* @total_req_bytes: total number of bytes processed (request).
*
* sg helper are used to iterate over the scatterlist. Since the size of the
* SRAM may be less than the scatter size, this struct struct is used to keep
@@ -60,7 +60,7 @@ struct req_progress {
/* dst mostly */
int sg_dst_left;
int dst_start;
- int total_req_bytes;
+ int hw_processed_bytes;
};
struct crypto_priv {
@@ -181,7 +181,7 @@ static void setup_data_in(void)
{
struct req_progress *p = &cpg->p;
p->crypt_len =
- min(p->hw_nbytes - p->total_req_bytes, cpg->max_req_size);
+ min(p->hw_nbytes - p->hw_processed_bytes, cpg->max_req_size);
copy_src_to_buf(p, cpg->sram + SRAM_DATA_IN_START,
p->crypt_len);
}
@@ -265,7 +265,7 @@ static void dequeue_complete_req(void)
int need_copy_len = cpg->p.crypt_len;
int sram_offset = 0;
- cpg->p.total_req_bytes += cpg->p.crypt_len;
+ cpg->p.hw_processed_bytes += cpg->p.crypt_len;
do {
int dst_copy;
@@ -291,7 +291,7 @@ static void dequeue_complete_req(void)
} while (need_copy_len > 0);
BUG_ON(cpg->eng_st != ENGINE_W_DEQUEUE);
- if (cpg->p.total_req_bytes < cpg->p.hw_nbytes) {
+ if (cpg->p.hw_processed_bytes < cpg->p.hw_nbytes) {
/* process next scatter list entry */
cpg->eng_st = ENGINE_BUSY;
mv_process_current_q(0);
reply other threads:[~2010-04-08 16:29 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4BBE045C.5000900@jdland.co.il \
--to=uri@jdland.co.il \
--cc=herbert@gondor.apana.org.au \
--cc=linux-crypto@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -42,7 +42,7 @@ enum engine_status {
* @sg_dst_left: bytes left dst to process in this scatter list
* @dst_start: offset to add to dst start position (scatter list)
- * @total_req_bytes: total number of bytes processed (request).
+ * @hw_processed_bytes: number of bytes processed by hw (request).
*
* sg helper are used to iterate over the scatterlist. Since the size of the
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.